@@ -17,7 +17,7 @@ import Foundation
 @unsafe private let deviceContactCallback: MTContactCallbackFunction = {
     device, touches, numTouches, timestamp, frame in
     #if DEBUG
-        unsafe touchCount += 1
+        touchCount += 1
         // Log sparingly to avoid performance impact
         if unsafe touchCount <= 5 || touchCount % 500 == 0 {
             Log.debug(unsafe "Touch callback #\(touchCount): \(numTouches) touches", category: .device)
